==> server-api-impl-10.2.0-630.748-sources.jar: com/xebialabs/deployit/core/rest/api/SessionServiceImpl.scala <==
package com.xebialabs.deployit.core.rest.api

import com.xebialabs.deployit.core.api.SessionService
import com.xebialabs.deployit.core.api.dto.{ActiveUserSession, UserSessionsOverview}
import com.xebialabs.deployit.core.rest.secured.AbstractSecuredResource
import com.xebialabs.deployit.core.service.PaginationService
import com.xebialabs.deployit.engine.api.dto.{Ordering, Paging}
import com.xebialabs.deployit.repository.XldSessionRepository
import com.xebialabs.deployit.security.permission.PlatformPermissions.{EDIT_SECURITY, VIEW_SECURITY}
import org.jboss.resteasy.spi.HttpResponse
import org.springframework.stereotype.Service

import java.util
import javax.ws.rs.core.Context
import scala.jdk.CollectionConverters._

@Service
class SessionServiceImpl(xldSessionRepository: XldSessionRepository, paginationService: PaginationService)
  extends AbstractSecuredResource with SessionService {
  @Context val response: HttpResponse = null

  override def getActiveSessions(principalPattern: String,
                                 paging: Paging,
                                 order: Ordering): util.List[ActiveUserSession] = {
    checkPermissions(EDIT_SECURITY, VIEW_SECURITY)

    val principalPatternOption = Option(principalPattern).getOrElse("")
    paginationService.addPagingHeaderIfNeeded(
      paginationService.toSetHeader(response),
      () => xldSessionRepository.count(principalPatternOption),
      paging
    )
    xldSessionRepository.findAll(principalPatternOption, paging, order).asJava
  }

  override def getSessionsOverview: UserSessionsOverview = {
    checkPermissions(EDIT_SECURITY, VIEW_SECURITY)
    xldSessionRepository.getSessionSummary
  }
}

==> server-api-impl-10.3.0-719.1348-sources.jar: com/xebialabs/deployit/core/rest/api/SessionServiceImpl.scala <==
package com.xebialabs.deployit.core.rest.api

import com.xebialabs.deployit.core.api.SessionService
import com.xebialabs.deployit.core.api.dto.{ActiveUserSession, UserSessionsOverview}
import com.xebialabs.deployit.core.rest.secured.AbstractSecuredResource
import com.xebialabs.deployit.engine.api.dto.{Ordering, Paging}
import com.xebialabs.deployit.repository.XldSessionRepository
import com.xebialabs.deployit.security.permission.PlatformPermissions.{EDIT_SECURITY, VIEW_SECURITY}
import org.jboss.resteasy.spi.HttpResponse
import org.springframework.stereotype.Service
import java.util

import ai.digital.deploy.sql.http.enricher.PaginationService
import javax.ws.rs.core.Context

import scala.jdk.CollectionConverters._

@Service
class SessionServiceImpl(xldSessionRepository: XldSessionRepository, paginationService: PaginationService)
  extends AbstractSecuredResource with SessionService {
  @Context val response: HttpResponse = null

  override def getActiveSessions(principalPattern: String,
                                 paging: Paging,
                                 order: Ordering): util.List[ActiveUserSession] = {
    checkPermissions(EDIT_SECURITY, VIEW_SECURITY)

    val principalPatternOption = Option(principalPattern).getOrElse("")
    paginationService.addPagingHeaderIfNeeded(
      paginationService.toSetHeader(response),
      () => xldSessionRepository.count(principalPatternOption),
      paging
    )
    xldSessionRepository.findAll(principalPatternOption, paging, order).asJava
  }

  override def getSessionsOverview: UserSessionsOverview = {
    checkPermissions(EDIT_SECURITY, VIEW_SECURITY)
    xldSessionRepository.getSessionSummary
  }
}
